# SupremeUtils

A python package capable of doing some useful things to help you on your code

## Installation

Under development, avaliable on PyPi soon

## Usage

Documentation will be written soon


*Written by SystemFall*
